@@ -1,12 +1,12 @@
 //! This module contains the `Flag` enum, used to store flags of a particular node
 use super::Network;
-use crate::error::CnErr;
+use crate::cn;
 use rustc_hash::FxHashMap as HashMap;
 use serde::{Serialize, Deserialize};
 
 /// `Flag` is used to store specific information about a given node.
 #[derive(Debug, Clone, Serialize, Deserialize)]
-pub enum FlagContent {
+pub enum Flag {
     /// String flag
     Str(String),
     /// Unsigned integer flag
@@ -27,23 +27,23 @@ impl Network {
         &mut self,
         index: usize,
         name: &str,
-        content: FlagContent,
-    ) -> Result<Option<FlagContent>, CnErr> {
+        content: Flag,
+    ) -> Result<Option<Flag>, cn::Err> {
         Ok(self.get_mut(index)?.flags.insert(name.to_string(), content))
     }
 
     /// Remove a flag with specified name. Returns the contents or `None` if flag was not set.
     /// Returns `Err` if specified node does not exist.
-    pub fn unflag(&mut self, index: usize, name: &str) -> Result<Option<FlagContent>, CnErr> {
+    pub fn unflag(&mut self, index: usize, name: &str) -> Result<Option<Flag>, cn::Err> {
         Ok(self.get_mut(index)?.flags.remove(name))
     }
 
     /// Get all nodes containing a given flag. Returns HashMap of (node index, flag value) pairs.
-    pub fn flagged(&self, name: &str) -> HashMap<usize, FlagContent> {
+    pub fn flagged(&self, name: &str) -> HashMap<usize, Flag> {
         self.nodes()
             .filter(|node| node.flags().contains_key(name))
             .map(|node| (*node.index(), node.flags()[name].clone()))
-            .collect::<HashMap<usize, FlagContent>>()
+            .collect::<HashMap<usize, Flag>>()
     }
 
     /// Get all nodes not containing a given flag. Returns vector of node indexes.
