@@ -5,12 +5,10 @@ mod props;
 mod link;
 mod models;
 
-pub use link::*;
+pub use link::Weight;
 pub use models::Model;
-pub use new::*;
-pub use props::*;
 
-use crate::Node;
+use crate::node::Node;
 use rand_xoshiro::Xoshiro256Plus;
 use serde::{Deserialize, Serialize};
 use std::cell::RefCell;
