@@ -2,14 +2,14 @@
 
 use super::Network;
 use crate::algorithms;
-use crate::CnErr;
+use crate::cn;
 
 use rand::prelude::*;
 use serde::{Deserialize, Serialize};
 
-/// `Model` decides the algorithm used to connect the nodes during `Network`'s
-/// initialization.
-#[derive(Debug, Clone, Serialize, Deserialize)]
+/// Decides the algorithm used to connect the nodes during [`Network`]'s initialization. It can
+/// also be used for identification purposes when the [`Model::Custom`] variant is used.
+#[derive(Debug, Clone, PartialEq, Serialize, Deserialize)]
 pub enum Model {
     /// The Erdos–Renyi random network model.
     ER {
@@ -24,26 +24,29 @@ pub enum Model {
         m0: usize,
         /// The number of nodes added in each step during network creation.
         /// Keep in mind that this should be strictly less or equal m0 and the Barabasi-Albert
-        /// initialization fuction **will panic** if this is not the case.
+        /// initialization function **will panic** if this is not the case.
         m: usize,
     },
-    /// Placeholder for a network with no connections.
+    /// Custom model, can be dynamically assigned to a network using [`Network::set_model`].
+    Custom(String),
+    /// Placeholder for a network with no specified model. When a network is initialized with this
+    /// model no immediate connections will be made.
     None,
 }
 
 impl Model {
     /// Initialize (or reinitialize) the network's links according to the Erdos-Renyi model.
-    /// See the [Model](enum.Model.html) for more detailed explanation.
+    /// See [`Model::ER`] for more detailed explanation.
     ///
     /// If `whole` is `true` then the network is artificially stitched together after
     /// initialization, otherwise there is no guarantee that there are no 'outsiders' or even
     /// separate networks.
     ///
-    /// Beware that the network is **not** cleared before linking.
+    /// Beware that the network is **not** cleared, hence any existing links will remain.
     pub fn init_er(net: &mut Network, p: f64, whole: bool) {
         let net_len = *net.size();
         if p <= 0. || p > 1. {
-            panic!("{}", CnErr::BadProbability(p));
+            panic!("{}", cn::Err::BadProbability(p));
         }
         for i in 0..net_len {
             for j in i + 1..net_len {
