@@ -1,6 +1,6 @@
-use crate::FlagContent;
+use crate::flag::Flag;
 use rustc_hash::FxHashMap as HashMap;
-use serde::{Serialize, Deserialize};
+use serde::{Deserialize, Serialize};
 
 /// `Node` is a single vertex in the graph-like data structure.
 #[derive(Debug, Clone, Serialize, Deserialize)]
@@ -12,13 +12,13 @@ pub struct Node {
     /// parent network.
     links: HashMap<usize, f64>,
     /// The flag hashmap
-    pub(crate) flags: HashMap<String, FlagContent>,
+    pub(crate) flags: HashMap<String, Flag>,
     /// The node degree
     deg: usize,
 }
 
 impl Node {
-    /// Creates a new, empty node
+    /// Create a new, empty node
     pub(crate) fn new(index: usize) -> Self {
         Node {
             index,
@@ -51,17 +51,17 @@ impl Node {
         self.links.clear()
     }
 
-    /// Return non-mutable reference to the node links.
+    /// Get non-mutable reference to the node links.
     pub fn links(&self) -> &HashMap<usize, f64> {
         &self.links
     }
 
     /// Return non-mutable reference to the node flags.
-    pub fn flags(&self) -> &HashMap<String, FlagContent> {
+    pub fn flags(&self) -> &HashMap<String, Flag> {
         &self.flags
     }
 
-    // Calculate node degree, ie. number of closest neighbors
+    // Get node degree, ie. number of closest neighbors
     pub fn deg(&self) -> &usize {
         &self.deg
     }
