@@ -23,8 +23,8 @@ fn test_link() {
     assert!((net.get_link(2, 3).unwrap().unwrap() - 0.25).abs() < f64::EPSILON);
     assert!((net.get_link(3, 2).unwrap().unwrap() - 0.25).abs() < f64::EPSILON);
 
-    assert_eq!(net.link(1, 100).unwrap_err(), CnErr::NoSuchNode(100));
-    assert_eq!(net.get_link(1, 100).unwrap_err(), CnErr::NoSuchNode(100));
+    assert_eq!(net.link(1, 100).unwrap_err(), cn::Err::NoSuchNode(100));
+    assert_eq!(net.get_link(1, 100).unwrap_err(), cn::Err::NoSuchNode(100));
 }
 
 #[test]
@@ -37,8 +37,8 @@ fn test_unlink() {
     assert_eq!(net.get_link(0, 1).unwrap(), None);
     assert_eq!(net.get_link(1, 0).unwrap(), None);
 
-    assert_eq!(net.unlink(0, 100).unwrap_err(), CnErr::NoSuchNode(100));
-    assert_eq!(net.unlink_safe(0, 100).unwrap_err(), CnErr::NoSuchNode(100));
+    assert_eq!(net.unlink(0, 100).unwrap_err(), cn::Err::NoSuchNode(100));
+    assert_eq!(net.unlink_safe(0, 100).unwrap_err(), cn::Err::NoSuchNode(100));
 
     net.link(0, 1).unwrap();
     net.link(1, 2).unwrap();
@@ -68,7 +68,7 @@ fn test_disconnect() {
     assert_eq!(net.disconnect(0).unwrap(), HashMap::default());
     assert!((net.disconnect(1).unwrap()[&2] - 1.0).abs() < f64::EPSILON);
     assert_eq!(net.disconnect(2).unwrap(), HashMap::default());
-    assert_eq!(net.disconnect(100).unwrap_err(), CnErr::NoSuchNode(100));
+    assert_eq!(net.disconnect(100).unwrap_err(), cn::Err::NoSuchNode(100));
 }
 
 #[test]
@@ -81,7 +81,7 @@ fn test_attach_detach() {
     assert_eq!(net.size_connected(), 0);
     assert_eq!(net.indexes().collect::<Vec<_>>(), vec![0,1,2]);
 
-    assert_eq!(net.attach(&[0, 3, 4]).unwrap_err(), CnErr::NodeExists(0));
+    assert_eq!(net.attach(&[0, 3, 4]).unwrap_err(), cn::Err::NodeExists(0));
     for i in 0..3 {
         assert!(net.get(i).is_ok());
     }
