@@ -8,7 +8,7 @@ fn test_get() {
         assert!(net.get(i).is_ok());
     }
     for i in 3..100 {
-        assert_eq!(net.get(i).unwrap_err(), CnErr::NoSuchNode(i));
+        assert_eq!(net.get(i).unwrap_err(), cn::Err::NoSuchNode(i));
     }
 }
 
@@ -19,19 +19,25 @@ fn test_degs() {
     net.link(0, 2).unwrap();
 
     assert_eq!(net[0].deg(), &2);
-    let map = vec![(1, 1.0), (2, 1.0)].into_iter().collect();
-    assert_eq!(net[0].links(), &map);
+    assert_eq!(
+        net[0].links(),
+        &vec![(1, 1.0), (2, 1.0)].into_iter().collect()
+    );
 
     assert_eq!(net[1].deg(), &1);
-    let map = vec![(0, 1.0)].into_iter().collect();
-    assert_eq!(net[1].links(), &map);
+    assert_eq!(net[1].links(), &vec![(0, 1.0)].into_iter().collect());
 
     assert_eq!(net[2].deg(), &1);
     assert_eq!(net.total_deg(), 4);
     assert_eq!(net.edges(), 2);
 
-    let map = vec![(1, 2), (2, 1)].into_iter().collect();
-    assert_eq!(net.deg_distr(), map);
+    assert_eq!(net.deg_distr(), vec![(1, 2), (2, 1)].into_iter().collect());
 }
 
-
+#[test]
+fn test_model() {
+    let mut net = Network::new(3, Model::None, Weight::default());
+    let name = "custom model name".to_string();
+    net.set_model(&name);
+    assert_eq!(net.model(), &Model::Custom(name));
+}
